﻿using Telerik.Windows.Controls.Book;
using Telerik.Windows.Controls;
using System;
using System.ComponentModel;
using System.Collections;
using Telerik.Windows;

namespace SilverlightApplication1
{
	public class MyBookPagedCollectionView : IPagedCollectionView, IEnumerable, INotifyPropertyChanged
	{
		private RadBook owner;

		/// <summary>
		/// Initializes a new instance of the <see cref="BookPagedCollectionView"/> class.
		/// </summary>
		/// <param name="owner">The owner.</param>
		public MyBookPagedCollectionView(RadBook owner)
		{
			this.owner = owner;
			this.owner.PageChanged += this.Book_PageChanged;
			//this.owner.ItemsCountChanged += this.Book_ItemsCountChanged;
		}

		/// <summary>
		/// Occurs when page has changed.
		/// </summary>
		public event EventHandler<EventArgs> PageChanged;

		/// <summary>
		/// Occurs when a property has changed value.
		/// </summary>
		public event PropertyChangedEventHandler PropertyChanged;

		/// <summary>
		/// Occurs when a page is changing.
		/// </summary>
		public event EventHandler<PageChangingEventArgs> PageChanging;

		/// <summary>
		/// Gets a value that indicates whether the <see cref="P:Telerik.Windows.Data.IPagedCollectionView.PageIndex"/> value is allowed to change.
		/// </summary>
		/// <returns>true if the <see cref="P:Telerik.Windows.Data.IPagedCollectionView.PageIndex"/> value is allowed to change; otherwise, false.</returns>
		public bool CanChangePage
		{
			get
			{
				return true;
			}
		}

		/// <summary>
		/// Gets a value that indicates whether a page index change is in process.
		/// </summary>
		/// <returns>true if the page index is changing; otherwise, false.</returns>
		public bool IsPageChanging
		{
			get
			{
				return false;
			}
		}

		/// <summary>
		/// Gets the minimum number of items known to be in the source collection.
		/// </summary>
		/// <returns>The minimum number of items known to be in the source collection.</returns>
		public int ItemCount
		{
			get
			{
				return this.owner.Items.Count;
			}
		}

		/// <summary>
		/// Gets the zero-based index of the current page.
		/// </summary>
		/// <returns>The zero-based index of the current page.</returns>
		public int PageIndex
		{
			get
			{
				//int newPageIndex = RadBook.ConvertPageToSheetIndex(this.owner.RightPageIndex, this.owner.FirstPagePosition);
				return this.owner.RightPageIndex;
			}
		}

		/// <summary>
		/// Gets or sets the number of items to display on a page.
		/// </summary>
		/// <returns>The number of items to display on a page.</returns>
		public int PageSize
		{
			get
			{
				return 1;
			}
			set
			{
				// do nothing
			}
		}

		/// <summary>
		/// Gets the total number of items in the source collection.
		/// </summary>
		/// <returns>The total number of items in the source collection, or -1 if the total number is unknown.</returns>
		public int TotalItemCount
		{
			get
			{
				return this.ItemCount;
			}
		}

		/// <summary>
		/// Sets the first page as the current page.
		/// </summary>
		public bool MoveToFirstPage()
		{
			this.owner.FirstPage();
			return true;
		}

		/// <summary>
		/// Sets the last page as the current page.
		/// </summary>
		public bool MoveToLastPage()
		{
			this.owner.LastPage();
			return true;
		}

		/// <summary>
		/// Moves to the page after the current page.
		/// </summary>
		public bool MoveToNextPage()
		{
			this.owner.NextPage();
			return true;
		}

		/// <summary>
		/// Requests a page move to the page at the specified index.
		/// </summary>
		/// <param name="pageIndex">The index of the page to move to.</param>
		public bool MoveToPage(int pageIndex)
		{
			this.owner.RightPageIndex = pageIndex;

			return true;
		}

		/// <summary>
		/// Moves to the page before the current page.
		/// </summary>
		public bool MoveToPreviousPage()
		{
			this.owner.PreviousPage();
			return true;
		}

		/// <summary>
		/// Returns an enumerator that iterates through a collection.
		/// </summary>
		/// <returns>
		/// An <see cref="T:System.Collections.IEnumerator"/> object that can be used to iterate through the collection.
		/// </returns>
		public IEnumerator GetEnumerator()
		{
			return (this.owner.Items as IEnumerable).GetEnumerator();
		}

		private void Book_PageChanged(object sender, RadRoutedEventArgs e)
		{
			this.OnPageChanged();
			this.OnPropertyChanged("PageIndex");
		}
		private void OnPageChanged()
		{
			if (this.PageChanged != null)
			{
				this.PageChanged(this, EventArgs.Empty);
			}
		}
		private void OnPropertyChanged(string propertyName)
		{
			if (this.PropertyChanged != null)
			{
				this.PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
			}
		}

	}
}
